OC.L10N.register(
    "files",
    {
    "File could not be found" : "File could not be found",
    "Move or copy" : "Move or copy",
    "Download" : "Download",
    "Delete" : "Delete",
    "Tags" : "Tags",
    "Show list view" : "Show list view",
    "Show grid view" : "Show grid view",
    "Home" : "Home",
    "Close" : "Close",
    "Could not create folder \"{dir}\"" : "Could not create folder \"{dir}\"",
    "This will stop your current uploads." : "This will stop your current uploads.",
    "Upload cancelled." : "Upload cancelled.",
    "Processing files …" : "Processing files …",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Unable to upload {filename} as it is a directory or has 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Not enough free space, you are uploading {size1} but only {size2} is left",
    "Target folder \"{dir}\" does not exist any more" : "Target folder \"{dir}\" does not exist any more",
    "Not enough free space" : "Not enough free space",
    "An unknown error has occurred" : "An unknown error has occurred",
    "File could not be uploaded" : "File could not be uploaded",
    "Uploading …" : "Uploading …",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "Uploading … ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} of {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Uploading that item is not supported",
    "Target folder does not exist any more" : "Target folder does not exist any more",
    "Operation is blocked by access control" : "Operation is blocked by access control",
    "Error when assembling chunks, status code {status}" : "Error when assembling chunks, status code {status}",
    "Actions" : "Actions",
    "Rename" : "Rename",
    "Move" : "Move",
    "Copy" : "Copy",
    "Choose target folder" : "Choose target folder",
    "Set reminder" : "Set reminder",
    "Edit locally" : "Edit locally",
    "Open" : "Open",
    "Could not load info for file \"{file}\"" : "Could not load info for file \"{file}\"",
    "Files" : "ფაილები",
    "Details" : "Details",
    "Please select tag(s) to add to the selection" : "Please select tag(s) to add to the selection",
    "Apply tag(s) to selection" : "Apply tag(s) to selection",
    "Select directory \"{dirName}\"" : "Select directory \"{dirName}\"",
    "Select file \"{fileName}\"" : "Select file \"{fileName}\"",
    "Pending" : "Pending",
    "Unable to determine date" : "Unable to determine date",
    "This operation is forbidden" : "This operation is forbidden",
    "This directory is unavailable, please check the logs or contact the administrator" : "This directory is unavailable, please check the logs or contact the administrator",
    "Storage is temporarily not available" : "Storage is temporarily not available",
    "Could not move \"{file}\", target exists" : "Could not move \"{file}\", target exists",
    "Could not move \"{file}\"" : "Could not move \"{file}\"",
    "copy" : "copy",
    "Could not copy \"{file}\", target exists" : "Could not copy \"{file}\", target exists",
    "Could not copy \"{file}\"" : "Could not copy \"{file}\"",
    "Copied {origin} inside {destination}" : "Copied {origin} inside {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Copied {origin} and {nbfiles} other files inside {destination}",
    "Failed to redirect to client" : "Failed to redirect to client",
    "{newName} already exists" : "{newName} already exists",
    "Could not rename \"{fileName}\", it does not exist any more" : "Could not rename \"{fileName}\", it does not exist any more",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name.",
    "Could not rename \"{fileName}\"" : "Could not rename \"{fileName}\"",
    "Could not create file \"{file}\"" : "Could not create file \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Could not create file \"{file}\" because it already exists",
    "Could not create folder \"{dir}\" because it already exists" : "Could not create folder \"{dir}\" because it already exists",
    "Could not fetch file details \"{file}\"" : "Could not fetch file details \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Error deleting file \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "No search results in other folders for {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Enter more than two characters to search in other folders",
    "Name" : "Name",
    "Size" : "Size",
    "Modified" : "Modified",
    "_%n folder_::_%n folders_" : ["%n folder","%n folders"],
    "_%n file_::_%n files_" : ["%n file","%n files"],
    "{dirs} and {files}" : "{dirs} and {files}",
    "_including %n hidden_::_including %n hidden_" : ["including %n hidden","including %n hidden"],
    "You do not have permission to upload or create files here" : "You do not have permission to upload or create files here",
    "_Uploading %n file_::_Uploading %n files_" : ["Uploading %n file","Uploading %n files"],
    "New" : "New",
    "New file/folder menu" : "New file/folder menu",
    "Select file range" : "Select file range",
    "{used}%" : "{used}%",
    "{used} of {quota} used" : "{used} of {quota} used",
    "{used} used" : "{used} used",
    "\"{name}\" is an invalid file name." : "\"{name}\" is an invalid file name.",
    "File name cannot be empty." : "File name cannot be empty.",
    "\"/\" is not allowed inside a file name." : "\"/\" is not allowed inside a file name.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" is not an allowed filetype",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Storage of {owner} is full, files cannot be updated or synced anymore!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Your storage is full, files cannot be updated or synced anymore!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Storage of {owner} is almost full ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Your storage is almost full ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["matches \"{filter}\"","match \"{filter}\""],
    "View in folder" : "View in folder",
    "Path" : "Path",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Favorited",
    "Favorite" : "Favorite",
    "New folder" : "New folder",
    "Create new folder" : "Create new folder",
    "Upload file" : "Upload file",
    "Recent" : "Recent",
    "Not favorited" : "Not favorited",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "An error occurred while trying to update the tags" : "An error occurred while trying to update the tags",
    "Added to favorites" : "Added to favorites",
    "Removed from favorites" : "Removed from favorites",
    "You added {file} to your favorites" : "You added {file} to your favorites",
    "You removed {file} from your favorites" : "You removed {file} from your favorites",
    "Favorites" : "Favorites",
    "File changes" : "File changes",
    "Created by {user}" : "Created by {user}",
    "Changed by {user}" : "Changed by {user}",
    "Deleted by {user}" : "Deleted by {user}",
    "Restored by {user}" : "Restored by {user}",
    "Renamed by {user}" : "Renamed by {user}",
    "Moved by {user}" : "Moved by {user}",
    "You created {file}" : "You created {file}",
    "You created an encrypted file in {file}" : "You created an encrypted file in {file}",
    "{user} created {file}" : "{user} created {file}",
    "{user} created an encrypted file in {file}" : "{user} created an encrypted file in {file}",
    "{file} was created in a public folder" : "{file} was created in a public folder",
    "You changed {file}" : "You changed {file}",
    "You changed an encrypted file in {file}" : "You changed an encrypted file in {file}",
    "{user} changed {file}" : "{user} changed {file}",
    "{user} changed an encrypted file in {file}" : "{user} changed an encrypted file in {file}",
    "You deleted {file}" : "You deleted {file}",
    "You deleted an encrypted file in {file}" : "You deleted an encrypted file in {file}",
    "{user} deleted {file}" : "{user} deleted {file}",
    "{user} deleted an encrypted file in {file}" : "{user} deleted an encrypted file in {file}",
    "You restored {file}" : "You restored {file}",
    "{user} restored {file}" : "{user} restored {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "You renamed {oldfile} (hidden) to {newfile} (hidden)",
    "You renamed {oldfile} (hidden) to {newfile}" : "You renamed {oldfile} (hidden) to {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "You renamed {oldfile} to {newfile} (hidden)",
    "You renamed {oldfile} to {newfile}" : "You renamed {oldfile} to {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} renamed {oldfile} (hidden) to {newfile} (hidden)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} renamed {oldfile} (hidden) to {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} renamed {oldfile} to {newfile} (hidden)",
    "{user} renamed {oldfile} to {newfile}" : "{user} renamed {oldfile} to {newfile}",
    "You moved {oldfile} to {newfile}" : "You moved {oldfile} to {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} moved {oldfile} to {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "A file has been added to or removed from your <strong>favorites</strong>",
    "A file or folder has been <strong>changed</strong>" : "A file or folder has been <strong>changed</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "A favorite file or folder has been <strong>changed</strong>",
    "Upload (max. %s)" : "Upload (max. %s)",
    "Accept" : "Accept",
    "Reject" : "Reject",
    "Incoming ownership transfer from {user}" : "Incoming ownership transfer from {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour.",
    "Ownership transfer failed" : "Ownership transfer failed",
    "Your ownership transfer of {path} to {user} failed." : "Your ownership transfer of {path} to {user} failed.",
    "The ownership transfer of {path} from {user} failed." : "The ownership transfer of {path} from {user} failed.",
    "Ownership transfer done" : "Ownership transfer done",
    "Your ownership transfer of {path} to {user} has completed." : "Your ownership transfer of {path} to {user} has completed.",
    "The ownership transfer of {path} from {user} has completed." : "The ownership transfer of {path} from {user} has completed.",
    "in %s" : "in %s",
    "File Management" : "File Management",
    "Current directory path" : "Current directory path",
    "Reload current directory" : "Reload current directory",
    "Go to the \"{dir}\" directory" : "Go to the \"{dir}\" directory",
    "Drag and drop files here to upload" : "Drag and drop files here to upload",
    "Your have used your space quota and cannot upload files anymore" : "Your have used your space quota and cannot upload files anymore",
    "You don’t have permission to upload or create files here" : "You don’t have permission to upload or create files here",
    "\"{displayName}\" action executed successfully" : "\"{displayName}\" action executed successfully",
    "\"{displayName}\" action failed" : "\"{displayName}\" action failed",
    "Rename file" : "Rename file",
    "File name" : "File name",
    "Folder name" : "Folder name",
    "This node is unavailable" : "This node is unavailable",
    "Download file {name}" : "Download file {name}",
    "\"{name}\" is not an allowed filetype." : "\"{name}\" is not an allowed filetype.",
    "{newName} already exists." : "{newName} already exists.",
    "\"{char}\" is not allowed inside a file name." : "\"{char}\" is not allowed inside a file name.",
    "Name cannot be empty" : "Name cannot be empty",
    "Another entry with the same name already exists" : "Another entry with the same name already exists",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Renamed \"{oldName}\" to \"{newName}\"",
    "Could not rename \"{oldName}\", it does not exist any more" : "Could not rename \"{oldName}\", it does not exist any more",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name.",
    "Could not rename \"{oldName}\"" : "Could not rename \"{oldName}\"",
    "Total rows summary" : "Total rows summary",
    "\"{displayName}\" failed on some elements " : "\"{displayName}\" failed on some elements ",
    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" batch action executed successfully",
    "List of files and folders." : "List of files and folders.",
    "Column headers with buttons are sortable." : "Column headers with buttons are sortable.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list.",
    "File not found" : "File not found",
    "Storage informations" : "Storage informations",
    "{usedQuotaByte} used" : "{usedQuotaByte} used",
    "{relative}% used" : "{relative}% used",
    "Could not refresh storage stats" : "Could not refresh storage stats",
    "Your storage is full, files can not be updated or synced anymore!" : "Your storage is full, files can not be updated or synced anymore!",
    "Create" : "Create",
    "Transfer ownership of a file or folder" : "Transfer ownership of a file or folder",
    "Choose file or folder to transfer" : "Choose file or folder to transfer",
    "Change" : "Change",
    "New owner" : "New owner",
    "Choose a file or folder to transfer" : "Choose a file or folder to transfer",
    "Transfer" : "Transfer",
    "Transfer {path} to {userid}" : "Transfer {path} to {userid}",
    "Invalid path selected" : "Invalid path selected",
    "Unknown error" : "Unknown error",
    "Ownership transfer request sent" : "Ownership transfer request sent",
    "Cannot transfer ownership of a file or folder you do not own" : "Cannot transfer ownership of a file or folder you do not own",
    "Select file or folder to link to" : "Select file or folder to link to",
    "Choose file" : "Choose file",
    "Choose {file}" : "Choose {file}",
    "Loading current folder" : "Loading current folder",
    "No files in here" : "No files in here",
    "Upload some content or sync with your devices!" : "Upload some content or sync with your devices!",
    "Go to the previous folder" : "Go to the previous folder",
    "Go back" : "Go back",
    "Share" : "Share",
    "Shared by link" : "Shared by link",
    "Shared" : "Shared",
    "Switch to list view" : "Switch to list view",
    "Switch to grid view" : "Switch to grid view",
    "Error during upload: {message}" : "Error during upload: {message}",
    "Unknown error during upload" : "Unknown error during upload",
    "Open the files app settings" : "Open the files app settings",
    "Files settings" : "Files settings",
    "File cannot be accessed" : "File cannot be accessed",
    "Sort favorites first" : "Sort favorites first",
    "Show hidden files" : "Show hidden files",
    "Crop image previews" : "Crop image previews",
    "Enable the grid view" : "Enable the grid view",
    "Additional settings" : "Additional settings",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "WebDAV URL",
    "Copy to clipboard" : "Copy to clipboard",
    "Use this address to access your Files via WebDAV" : "Use this address to access your Files via WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "If you have enabled 2FA, you must create and use a new app password by clicking here.",
    "Clipboard is not available" : "Clipboard is not available",
    "WebDAV URL copied to clipboard" : "WebDAV URL copied to clipboard",
    "Unable to change the favourite state of the file" : "Unable to change the favourite state of the file",
    "Error while loading the file data" : "Error while loading the file data",
    "Pick a template for {name}" : "Pick a template for {name}",
    "Create a new file with the selected template" : "Create a new file with the selected template",
    "Creating file" : "Creating file",
    "Blank" : "Blank",
    "Unable to create new file from template" : "Unable to create new file from template",
    "Delete permanently" : "Delete permanently",
    "Cancel" : "Cancel",
    "Destination is not a folder" : "Destination is not a folder",
    "This file/folder is already in that directory" : "This file/folder is already in that directory",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "You cannot move a file/folder onto itself or into a subfolder of itself",
    "A file or folder with that name already exists in this folder" : "A file or folder with that name already exists in this folder",
    "The file does not exist anymore" : "The file does not exist anymore",
    "Choose destination" : "Choose destination",
    "Copy to {target}" : "Copy to {target}",
    "Move to {target}" : "Move to {target}",
    "Cancelled move or copy operation" : "Cancelled move or copy operation",
    "Open folder {displayName}" : "Open folder {displayName}",
    "Open in Files" : "Open in Files",
    "Open details" : "Open details",
    "Could not copy {file}. {message}" : "Could not copy {file}. {message}",
    "Could not move {file}. {message}" : "Could not move {file}. {message}",
    "Created new folder \"{name}\"" : "Created new folder \"{name}\"",
    "Filename" : "Filename",
    "Unable to initialize the templates directory" : "Unable to initialize the templates directory",
    "Create new templates folder" : "Create new templates folder",
    "Templates" : "Templates",
    "One of the dropped files could not be processed" : "One of the dropped files could not be processed",
    "Uploading \"{filename}\" failed" : "Uploading \"{filename}\" failed",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} folder","{folderCount} folders"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} file","{fileCount} files"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 file and {folderCount} folder","1 file and {folderCount} folders"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} file and 1 folder","{fileCount} files and 1 folder"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} files and {folderCount} folders",
    "List of favorites files and folders." : "List of favorites files and folders.",
    "No favorites yet" : "No favorites yet",
    "Files and folders you mark as favorite will show up here" : "Files and folders you mark as favorite will show up here",
    "All files" : "All files",
    "List of your files and folders." : "List of your files and folders.",
    "List of recently modified files and folders." : "List of recently modified files and folders.",
    "No recently modified files" : "No recently modified files",
    "Files and folders you recently modified will show up here." : "Files and folders you recently modified will show up here.",
    "No entries found in this folder" : "No entries found in this folder",
    "Select all" : "Select all",
    "Upload too large" : "Upload too large",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "The files you are trying to upload exceed the maximum size for file uploads on this server.",
    "Text file" : "Text file",
    "New text file.txt" : "New text file.txt",
    "Direct link was copied (only works for users who have access to this file/folder)" : "Direct link was copied (only works for users who have access to this file/folder)",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copy direct link (only works for users who have access to this file/folder)",
    "You can only favorite a single file or folder at a time" : "You can only favorite a single file or folder at a time",
    "\"remote user\"" : "\"remote user\"",
    "Search users" : "Search users",
    "You might not have have permissions to view it, ask the sender to share it" : "You might not have have permissions to view it, ask the sender to share it",
    "Set up templates folder" : "Set up templates folder",
    "Toggle %1$s sublist" : "Toggle %1$s sublist",
    "Toggle grid view" : "Toggle grid view",
    "Deleted files" : "Deleted files",
    "Shares" : "Shares",
    "Shared with others" : "Shared with others",
    "Shared with you" : "Shared with you",
    "Deleted shares" : "Deleted shares",
    "Pending shares" : "Pending shares",
    "This file has the tag {tag}" : "This file has the tag {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "This file has the tags {firstTags} and {lastTag}",
    "Select the row for {displayName}" : "Select the row for {displayName}",
    "Open folder {name}" : "Open folder {name}",
    "Unselect all" : "Unselect all",
    "ascending" : "ascending",
    "descending" : "descending",
    "Sort list by {column} ({direction})" : "Sort list by {column} ({direction})",
    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list.",
    "Search for an account" : "Search for an account",
    "Choose" : "Choose",
    "No files or folders have been deleted yet" : "No files or folders have been deleted yet",
    "Add" : "Add",
    "The files is locked" : "The files is locked"
},
"nplurals=2; plural=(n!=1);");
